SensorInfo class

Information about a single sensor's state.

Constructors

SensorInfo({required SensorName sensorName, required SensorStatus sensorStatus, required double frequency, required List<String> missingPermissions})
const
SensorInfo.fromMap(Map<String, dynamic> map)
factory

Properties

frequency double
final
hashCode int
The hash code for this object.
no setterinherited
missingPermissions List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorName SensorName
final
sensorStatus SensorStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited