SensorName enum

Names of sensors available in the SDK.

Inheritance
Available extensions

Values

status → const SensorName
magnetometer → const SensorName
gnss → const SensorName
barometer → const SensorName
accelerometer → const SensorName
gyroscope → const SensorName
location → const SensorName
customerMetadata → const SensorName
battery → const SensorName
connectivity → const SensorName
stepCounter → const SensorName
motionMode → const SensorName
wifiSignal → const SensorName
mobileDataSignal → const SensorName
rawLocation → const SensorName
fusedOrientation → const SensorName

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromNativeString(String value) SensorName

Constants

values → const List<SensorName>
A constant List of the values in this enum, in order of their declaration.