SensorStatistics class

Constructors

SensorStatistics({required String sensorName, required double configuredFrequencyHz, required double actualFrequencyHz, required SensorDataQuality quality})
const
SensorStatistics.fromMap(Map<String, dynamic> map)
factory

Properties

actualFrequencyHz double
final
configuredFrequencyHz double
final
hashCode int
The hash code for this object.
no setterinherited
quality SensorDataQuality
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited