TruemetricsStatusEvent class

A rich status event containing the state plus optional contextual data.

States that carry additional data:

Constructors

TruemetricsStatusEvent({required TruemetricsState state, String? deviceId, int? delayMs})
const

Properties

delayMs int?
final
deviceId String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state TruemetricsState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited