SensorDataQuality enum
Values
- excellent → const SensorDataQuality
-
95-100% of configured frequency
- good → const SensorDataQuality
-
80-95% of configured frequency
- poor → const SensorDataQuality
-
50-80% of configured frequency
- bad → const SensorDataQuality
-
Less than 50% of configured frequency
- unknown → const SensorDataQuality
-
No data available or sensor not recording
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromNativeString(
String value) → SensorDataQuality
Constants
-
values
→ const List<
SensorDataQuality> - A constant List of the values in this enum, in order of their declaration.