TruemetricsState enum
Values
- uninitialized → const TruemetricsState
-
SDK is not initialized. From here, SDK can transition to INITIALIZING or INITIALIZED state.
- initializing → const TruemetricsState
-
SDK is initializing — fetching configuration from the server. Retries automatically on recoverable errors (network failures, server 5xx). Transitions to INITIALIZED when config is available, or ERROR for non-recoverable errors.
- initialized → const TruemetricsState
-
SDK is initialized and ready to record sensor data. From here, SDK can transition to RECORDING_IN_PROGRESS or UNINITIALIZED states.
- delayedStart → const TruemetricsState
-
SDK initialization is delayed and will start automatically after the specified delay.
- recordingInProgress → const TruemetricsState
-
Recording sensor data is in progress. From here, SDK can transition to RECORDING_STOPPED or UNINITIALIZED states.
- recordingStopped → const TruemetricsState
-
SDK is initialized but recording has been stopped. From here, SDK can transition to RECORDING_IN_PROGRESS or UNINITIALIZED states.
- trafficLimitReached → const TruemetricsState
-
Traffic limit has been reached.
- readingsDatabaseFull → const TruemetricsState
-
The readings database is full due to insufficient phone storage.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNativeString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromNativeString(
String nativeState) → TruemetricsState
Constants
-
values
→ const List<
TruemetricsState> - A constant List of the values in this enum, in order of their declaration.